%undefine _ld_as_needed

Summary:       Fortran 77 subroutines for solving large scale eigenvalue problems
Name:          arpack
Version:       3.9.0
Release:       3%{?dist}
License:       BSD
URL:           https://github.com/opencollab/arpack-ng
Source0:       %{url}/archive/%{version}/arpack-ng-%{version}.tar.gz

BuildRequires: gcc-c++ gcc-gfortran pkgconfig(flexiblas) libtool make
Provides:      arpack-ng = %{version}-%{release}

%description
ARPACK is a collection of Fortran 77 subroutines designed to solve large scale eigenvalue problems.

The package is designed to compute a few eigenvalues and corresponding eigenvectors of a general n
by n matrix A. It is most appropriate for large sparse or structured matrices A where structured
means that a matrix-vector product w <- Av requires order n rather than the usual order n**2
floating point operations. This software is based upon an algorithmic variant of the Arnoldi process
called the Implicitly Restarted Arnoldi Method (IRAM).

%package devel
Summary:    Files needed for developing arpack based applications
Requires:    arpack = %{version}-%{release}
Provides:    arpack-ng-devel = %{version}-%{release}

%description devel
ARPACK is a collection of Fortran 77 subroutines designed to solve large scale eigenvalue problems.
This package contains the so library links used for building arpack based applications.

%package static
Summary:    Static library for developing arpack based applications
Requires:    arpack-devel = %{version}-%{release}
Provides:    arpack-ng-static = %{version}-%{release}

%description static
ARPACK is a collection of Fortran 77 subroutines designed to solve large scale eigenvalue problems.
This package contains the static library and so links used for building arpack based applications.

%prep
%setup -qc
mv arpack-ng-%{version} src
pushd src
autoreconf -vif
popd
cp -pr src src64

%build
pushd src
%configure \
    --enable-shared \
    --enable-static \
    --with-blas=-lflexiblas \
    --with-lapack=-lflexiblas \
    --enable-icb \
    %{nil}

%make_build
popd
pushd src64
%configure \
    --enable-shared \
    --enable-static \
    LIBSUFFIX=64 \
    INTERFACE64=1 \
    --with-blas=-lflexiblas64 \
    --with-lapack=-lflexiblas64 \
    --enable-icb \
    %{nil}

%make_build
popd

%install
pushd src
%make_install
popd
pushd src64
%make_install
popd
rm -r %{buildroot}%{_libdir}/*.la

%check
pushd src
%make_build check
pushd EXAMPLES ; make clean ; popd
popd
pushd src64
%make_build check
pushd EXAMPLES ; make clean ; popd
popd

%files
%license src/COPYING
%doc src/CHANGES src/README.md
%{_libdir}/libarpack.so.*
%{_libdir}/libarpack64.so.*

%files devel
%doc src/EXAMPLES/ src/DOCUMENTS/
%doc src/CHANGES src/README.md
%{_libdir}/libarpack.so
%{_libdir}/libarpack64.so
%{_includedir}/arpack-ng
%{_libdir}/pkgconfig/*.pc

%files static
%{_libdir}/libarpack.a
%{_libdir}/libarpack64.a

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.9.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.9.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 18 2023 Shuo Wang <abushwang@tencent.com> - 3.9.0-1
- initial build
